==> bouml_2.7.4.tar.gz: bouml_2.7.4/genplugouts/xmi/UmlItem.cpp <==

#include "UmlItem.h"
#include "FileOut.h"

#include "UmlCom.h"
 UmlItem::~UmlItem() {
}

void UmlItem::xmi() {
  UmlCom::trace("Error : must be applied on a package<br>");
}

bool UmlItem::write_if_needed(FileOut & out) {
  const QVector<UmlItem> ch = children();
  unsigned n = ch.size();
  bool used = FALSE;
  
  for (unsigned i = 0; i != n; i += 1)
    used |= ch[i]->write_if_needed(out);

  return used;
}

void UmlItem::write(FileOut & out) {
  if (! _written) {
    _written = TRUE;
    
    parent()->write(out);
  }
}

void UmlItem::write_stereotype(FileOut & out) {
  if (! stereotype().isEmpty()) {
    out.indent(); 
    out << "<UML:ModelElement.stereotype>\n"; 
    out.indent(); 
    out << "\t<UML:Stereotype name=\"" << stereotype() << "\"/>\n";
    out.indent(); 
    out << "</UML:ModelElement.stereotype>\n"; 

    out.indent(); 
    out << "<UML:ModelElement.taggedValue>\n"; 
    out.indent(); 
    out << "\t<UML:TaggedValue tag=\"stereotype\" value=\"" << stereotype() << "\"/>\n";
    out.indent(); 
    out << "</UML:ModelElement.taggedValue>\n"; 
  }

}

void UmlItem::write_description(FileOut & out) {
  if (! description().isEmpty()) {
    out.indent();
    out << "<UML:ModelElement.taggedValue>\n";
    out.indent();
    out << "\t<UML:TaggedValue tag=\"documentation\" value=\"";
    
    for (const char * p = description(); *p != 0; p += 1) {
      switch (*p) {
      case '<': out << "&lt;"; break;
      case '>': out << "&gt;"; break;
      case '"': out << "&quot;"; break;
      case '&': out << "&amp;"; break;
      default: out << *p;
      }
    }
    
    out << "\"/>\n";
    out.indent();
    out << "</UML:ModelElement.taggedValue>\n";
  }

}

void UmlItem::ref(FileOut & out) {
  // theorically not called
  out << "<UML:???kind=" << kind() << "??? ";
  out.idref(this); 
  out << "/>"; 
}

bool UmlItem::_gen_views;

==> bouml_2.9.3.tar.gz: bouml_2.9.3/genplugouts/xmi/UmlItem.cpp <==

#include "UmlItem.h"
#include "FileOut.h"

#include "UmlCom.h"
 UmlItem::~UmlItem() {
}

void UmlItem::xmi() {
  UmlCom::trace("Error : must be applied on a package<br>");
}

bool UmlItem::write_if_needed(FileOut & out) {
  const QVector<UmlItem> ch = children();
  unsigned n = ch.size();
  bool used = FALSE;
  
  for (unsigned i = 0; i != n; i += 1)
    used |= ch[i]->write_if_needed(out);

  return used;
}

void UmlItem::write(FileOut & out) {
  if (! _written) {
    _written = TRUE;
    
    parent()->write(out);
  }
}

void UmlItem::write_stereotype(FileOut & out) {
  if (! stereotype().isEmpty()) {
    out.indent(); 
    out << "<UML:ModelElement.stereotype>\n"; 
    out.indent(); 
    out << "\t<UML:Stereotype name=\"";
    out.quote(stereotype());
    out << "\"/>\n";
    out.indent(); 
    out << "</UML:ModelElement.stereotype>\n"; 

    out.indent(); 
    out << "<UML:ModelElement.taggedValue>\n"; 
    out.indent(); 
    out << "\t<UML:TaggedValue tag=\"stereotype\" value=\"";
    out.quote(stereotype());
    out << "\"/>\n";
    out.indent(); 
    out << "</UML:ModelElement.taggedValue>\n"; 
  }

}

void UmlItem::write_description_properties(FileOut & out) {
  const QDict<QCString> up = properties();
  
  if (!description().isEmpty() || !up.isEmpty()) {
    out.indent();
    out << "<UML:ModelElement.taggedValue>\n";
    
    if (! description().isEmpty()) {
      out.indent();
      out << "\t<UML:TaggedValue tag=\"documentation\" value=\"";
      out.quote(description());
      out << "\"/>\n";
    }
   
    QDictIterator<QCString> it(up);
    
    while (it.current()) {
      out.indent();
      out << "\t<UML:TaggedValue tag=\"";
      out.quote(it.currentKey());
      out << "\" value=\"";
      out.quote(*(it.current()));
      out << "\"/>\n";
      ++it;
    }
    
    out.indent();
    out << "</UML:ModelElement.taggedValue>\n";
  }
}

void UmlItem::ref(FileOut & out) {
  // theorically not called
  out << "<UML:???kind=" << kind() << "??? ";
  out.idref(this); 
  out << "/>"; 
}

bool UmlItem::_gen_views;

Language UmlItem::_lang;
